package com.ruoyi.web.controller.carrier;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.TdFileProvide;
import com.ruoyi.system.domain.carrier.TdCarrier;
import com.ruoyi.web.controller.manager.CarrierManager;
import com.ruoyi.web.controller.manager.SysAreaManager;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * packageName com.ruoyi.web.controller.carrier
 *
 * @author wangxy
 * @version JDK 8
 * @className CarrierController
 * @date 2024/8/21
 * @description 载体管理
 */
@Controller
@RequestMapping("/system/carrier")
public class CarrierController extends BaseController {

    private String prefix = "system/carrier";

    @Resource
    private CarrierManager carrierManager;

    @RequiresPermissions("system:carrier:view")
    @GetMapping()
    public String carrier() {
        return prefix + "/carrier";
    }

    /**
     * 载体列表
     */
    @RequiresPermissions("system:carrier:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdCarrier tdCarrier) {
        startPage();
        List<TdCarrier> carriers = carrierManager.selectTdCarrierList(tdCarrier);
        return getDataTable(carriers);
    }


    @Resource
    private SysAreaManager sysAreaManager;

    /**
     * 导出文件下发列表
     */
    @RequiresPermissions("system:carrier:export")
    @Log(title = "国家秘密载体", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TdCarrier tdCarrier) {
        List<TdCarrier> carriers = carrierManager.selectTdCarrierList(tdCarrier);
        carriers.forEach(tdCarrier1 -> {
            tdCarrier1.setAreaCity(sysAreaManager.getAreaName(tdCarrier1.getAreaCity()));
            tdCarrier1.setAreaDistrict(sysAreaManager.getAreaName(tdCarrier1.getAreaDistrict()));
        });
        ExcelUtil<TdCarrier> util = new ExcelUtil<>(TdCarrier.class);
        return util.exportExcel(carriers, "国家秘密载体数据");
    }

    /**
     * 新增载体
     */
    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    /**
     * 新增载体
     */
    @RequiresPermissions("system:carrier:add")
    @Log(title = "国家秘密载体", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TdCarrier tdCarrier) {
        return toAjax(carrierManager.saveOrUpdate(tdCarrier));
    }

    /**
     * 修改场国家秘密载体
     */
    @RequiresPermissions("system:carrier:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap) {
        TdCarrier tdCarrier = carrierManager.selectTdCarrier(id);
        mmap.put("tdCarrier", tdCarrier);
        return prefix + "/edit";
    }

    /**
     * 修改国家秘密载体
     */
    @RequiresPermissions("system:carrier:edit")
    @Log(title = "国家秘密载体", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TdCarrier tdCarrier) {
        return toAjax(carrierManager.saveOrUpdate(tdCarrier));
    }

    /**
     * 详情国家秘密载体
     */
    @RequiresPermissions("system:carrier:detail")
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap) {
        TdCarrier tdCarrier = carrierManager.selectTdCarrier(id);
        mmap.put("tdCarrier", tdCarrier);
        return prefix + "/detail";
    }

    /**
     * 删除国家秘密载体
     */
    @RequiresPermissions("system:carrier:remove")
    @Log(title = "国家秘密载体", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids) {
        return toAjax(carrierManager.deletedTdCarrierByids(ids));
    }

    /**
     * 修改状态
     */
    @GetMapping("/updateStatus/{id}/{status}")
    @ResponseBody
    public AjaxResult updateStatus(@PathVariable("id") String id, @PathVariable("status") String status) {
        return toAjax(carrierManager.updateStatus(id, status));
    }

}
