package com.ruoyi.web.controller.carrier;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.carrier.TdCarrier;
import com.ruoyi.web.controller.manager.CarrierManager;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 收发传递Controller
 */
@Controller
@RequestMapping("/system/recCarrier")
public class ReceiveCarrierController extends BaseController {
    private String prefix = "system/recCarrier";

    @Resource
    private CarrierManager carrierManager;

    @RequiresPermissions("system:recCarrier:view")
    @GetMapping()
    public String carrier() {
        return prefix + "/recCarrier";
    }

    /**
     * 载体列表
     */
    @RequiresPermissions("system:recCarrier:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdCarrier tdCarrier) {
        startPage();
        List<TdCarrier> carriers = carrierManager.selectTdCarrierList(tdCarrier);
        return getDataTable(carriers);
    }

    /**
     * 收发传递国家秘密载体
     */
    @RequiresPermissions("system:recCarrier:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap) {
        TdCarrier tdCarrier = carrierManager.selectTdCarrier(id);
        mmap.put("tdCarrier", tdCarrier);
        return prefix + "/edit";
    }

    /**
     * 收发传递国家秘密载体
     */
    @RequiresPermissions("system:recCarrier:edit")
    @Log(title = "载体收发传递", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TdCarrier tdCarrier) {
        return toAjax(carrierManager.saveOrUpdate(tdCarrier));
    }
}
