package com.ruoyi.web.controller.manager;

import cn.hutool.core.convert.Convert;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.ShiroUtils;
import com.ruoyi.system.domain.record.SysUserAfter;
import com.ruoyi.system.domain.record.SysUserBefore;
import com.ruoyi.system.domain.record.dto.UserRecordDTO;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.system.service.record.SysUserAfterService;
import com.ruoyi.system.service.record.SysUserBeforeService;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Objects;

/**
 * packageName com.ruoyi.web.controller.manager
 *
 * @author wangxy
 * @version JDK 8
 * @className UserRecordManager
 * @date 2024/8/21
 * @description 用户变更记录
 */
@Component
public class UserRecordManager {

    @Resource
    private SysUserBeforeService userBeforeService;


    @Resource
    private SysUserAfterService userAfterService;


    @Resource
    private ISysUserService userService;


    /**
     * 
     *  人员修改记录
     * @param user
     * @return boolean
     */
    @Transactional(rollbackFor = Exception.class)
    public boolean saveOrUpdate(SysUser user) {
        if(Objects.isNull(user)){
            throw new ServiceException("人员信息不能为空");
        }
        SysUser sysUser = userService.selectUserById(user.getUserId());
        SysUserBefore userBefore = Convert.convert(SysUserBefore.class, sysUser);
        userBefore.setCreateTime(new Date());
        userBefore.setCreateBy(ShiroUtils.getSysUser().getLoginName());
        userBeforeService.save(userBefore);
        SysUserAfter userAfter = Convert.convert(SysUserAfter.class, user);
        userAfter.setCreateTime(new Date());
        userAfter.setCreateBy(ShiroUtils.getSysUser().getLoginName());
        return userAfterService.save(userAfter);
    }



    public UserRecordDTO getUserRecordDTO( Long userId) {
        UserRecordDTO userRecordDTO = new UserRecordDTO();
         List<SysUserAfter> userAfters = userAfterService.lambdaQuery()
                 .eq(SysUserAfter::getUserId, userId)
                 .orderByDesc(SysUserAfter::getCreateTime).list();
        userRecordDTO.setUserAfterList(userAfters);
         List<SysUserBefore> userBefores = userBeforeService.lambdaQuery().eq(SysUserBefore::getUserId, userId)
                .orderByDesc(SysUserBefore::getCreateTime).list();
        userRecordDTO.setUserBeforeList(userBefores);
        return userRecordDTO;
    }


}
