package com.ruoyi.web.controller.system.property;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.utils.uuid.Seq;
import com.ruoyi.system.domain.TdPropertyEment;
import com.ruoyi.system.domain.TdPropertyInfo;
import com.ruoyi.web.controller.manager.TdPropertyEmentManager;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * packageName com.ruoyi.web.controller.system.property
 *
 * @author wangxy
 * @version JDK 8
 * @className TdPropertyEmentController
 * @date 2024/8/20
 * @description
 */
@Controller
@RequestMapping("/system/prementData")
public class TdPropertyEmentController extends BaseController {
    private String prefix = "system/property/ementdata";
    @Resource
    private TdPropertyEmentManager tdPropertyEmentManager;

    @RequiresPermissions("system:property:view")
    @GetMapping()
    public String tdEment() {
        return prefix + "/propertyEment";
    }

    /**
     * 设备列表
     */
    @RequiresPermissions("system:property:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdPropertyEment tdPropertyEment) {
        startPage();
        List<TdPropertyEment> tdPropertyEments = tdPropertyEmentManager.selectEmentList(tdPropertyEment);
        return getDataTable(tdPropertyEments);
    }


    /**
     * 导出设备管理列表
     */
    @RequiresPermissions("system:property:export")
    @Log(title = "涉密设备", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TdPropertyEment tdPropertyEment) {
        List<TdPropertyEment> tdPropertyEments = tdPropertyEmentManager.selectEmentList(tdPropertyEment);
        ExcelUtil<TdPropertyEment> util = new ExcelUtil<>(TdPropertyEment.class);
        return util.exportExcel(tdPropertyEments, "涉密设备数据");
    }

    /**
     * 新增设备
     */
    @GetMapping("/add/{useId}")
    public String add(@PathVariable("useId") String useId, ModelMap mmap) {
        mmap.put("useId", useId);
        return prefix + "/add";
    }

    /**
     * 新增设备
     */
    @RequiresPermissions("system:property:add")
    @Log(title = "涉密设备", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TdPropertyEment tdPropertyEment) {
        tdPropertyEment.setId("Ement_" + Seq.getId(Seq.commSeqType));
        tdPropertyEment.setMaintainState("1");
        return toAjax(tdPropertyEmentManager.saveOrUpdate(tdPropertyEment));
    }

    /**
     * 设备详情
     */
    @RequiresPermissions("system:property:detail")
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap) {
        TdPropertyEment tdPropertyEment = tdPropertyEmentManager.selecttdEment(id);
        mmap.put("tdPropertyEment", tdPropertyEment);
        return prefix + "/detail";
    }

    /**
     * 删除设备
     */
    @RequiresPermissions("system:property:remove")
    @Log(title = "涉密设备", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids) {
        return toAjax(tdPropertyEmentManager.deletedEmentByids(ids));
    }

    /**
     * 查询所有设备
     *
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    @PostMapping("/getList")
    @ResponseBody
    public AjaxResult getList() {
        return AjaxResult.success(tdPropertyEmentManager.selectList());
    }

}
